@@ -47,7 +47,7 @@ def womg_main(graph=None,
               items_descr_path=None,
               numb_topics=15,
               numb_docs=None,
-              numb_steps=100,
+              numb_steps=6,
               homophily=.5,
               gn_strength=13.,
               infl_strength=12.,
@@ -67,7 +67,7 @@ def womg_main(graph=None,
               alpha_value=2.,
               beta_value=2.,
               prop_steps=1000,
-              progress_bar=False,
+              progress_bar=True,
               save_all=False,
               save_int=False,
               save_infl=False,
@@ -221,7 +221,8 @@ def womg_main(graph=None,
         topic_model = LDA(numb_topics=numb_topics,
                           numb_docs=numb_docs,
                           docs_path=docs_path,
-                          items_descr_path=items_descr_path)
+                          items_descr_path=items_descr_path,
+                          progress_bar=progress_bar)
         topic_model.fit()
         #print(virality_exp)
         topic_model.set_docs_viralities(virality_exp=virality_exp)
@@ -256,7 +257,7 @@ def womg_main(graph=None,
 @click.option('--docs', metavar='D', default=None,
                     help='Number of docs to be generated. Default 100',
                     type=int)
-@click.option('--steps', metavar='T', default=100,
+@click.option('--steps', metavar='T', default=6,
                     help='Number of time steps for diffusion',
                     type=int)
 @click.option('--homophily', metavar='H', default=0.5,
